@@ -127,8 +127,8 @@ def run_notebook(args, ssh_config_check):
 
     if args.open_server:
         multi_platform_open('http://localhost:{0}'.format(args.port))
-        print 'A web browser should have opened to connect you to your notebook.'
-    print 'If no browser appears, or if you need to reopen a browser at any point, you should be able to point your browser to http://localhost:{0}'.format(args.port)
+        print('A web browser should have opened to connect you to your notebook.')
+    print('If no browser appears, or if you need to reopen a browser at any point, you should be able to point your browser to http://localhost:{0}'.format(args.port))
 
 
 def run_loupe(args):
@@ -145,7 +145,7 @@ def run_loupe(args):
 
     if args.open_server:
         multi_platform_open('http://localhost:{0}'.format(args.port))
-        print 'A web browser should have opened to connect you to your notebook.'
-    print 'If no browser appears, or if you need to reopen a browser at any point, you should be able to point your browser to http://localhost:{0}'.format(args.port)
-    print 'Your Loupe session is scheduled to terminate in {0}.  If you wish to terminate before this, please run:'.format(args.timeout)
-    print 'dx terminate {0}'.format(job_id)
+        print('A web browser should have opened to connect you to your notebook.')
+    print('If no browser appears, or if you need to reopen a browser at any point, you should be able to point your browser to http://localhost:{0}'.format(args.port))
+    print('Your Loupe session is scheduled to terminate in {0}.  If you wish to terminate before this, please run:'.format(args.timeout))
+    print('dx terminate {0}'.format(job_id))
