@@ -25,6 +25,7 @@ containers, dataobjects, apps, and jobs).
 from __future__ import print_function, unicode_literals, division, absolute_import
 
 import datetime, time, json, math, sys, copy
+import locale
 import subprocess
 from collections import defaultdict
 
@@ -380,7 +381,7 @@ def render_timestamp(timestamp):
     return datetime.datetime.fromtimestamp(timestamp//1000).ctime()
 
 
-FIELD_NAME_WIDTH = 20
+FIELD_NAME_WIDTH = 22
 
 
 def print_field(label, value):
@@ -410,7 +411,7 @@ def print_project_desc(desc, verbose=False):
         'id', 'class', 'name', 'summary', 'description', 'protected', 'restricted', 'created', 'modified',
         'dataUsage', 'sponsoredDataUsage', 'tags', 'level', 'folders', 'objects', 'permissions', 'properties',
         'appCaches', 'billTo', 'version', 'createdBy', 'totalSponsoredEgressBytes', 'consumedSponsoredEgressBytes',
-        'containsPHI', 'region', 'storageCost', 'pendingTransfer','atSpendingLimit',
+        'containsPHI', 'databaseUIViewOnly', 'region', 'storageCost', 'pendingTransfer','atSpendingLimit',
         # Following are app container-specific
         'destroyAt', 'project', 'type', 'app', 'appName'
     ]
@@ -444,6 +445,8 @@ def print_project_desc(desc, verbose=False):
         print_json_field("Restricted", desc["restricted"])
     if 'containsPHI' in desc:
         print_json_field('Contains PHI', desc['containsPHI'])
+    if 'databaseUIViewOnly' in desc and desc['databaseUIViewOnly']:
+        print_json_field('Database UI View Only', desc['databaseUIViewOnly'])
 
     # Usage
     print_field("Created", render_timestamp(desc['created']))
@@ -906,7 +909,7 @@ def print_execution_desc(desc):
                 else:
                     print_nofill_field(" sys reqs", YELLOW() + json.dumps(cloned_sys_reqs) + ENDC())
     if not desc.get('isFree') and desc.get('totalPrice') is not None:
-        print_field('Total Price', "$%.2f" % desc['totalPrice'])
+        print_field('Total Price', format_currency(desc['totalPrice'], meta=desc['currency']))
     if desc.get('invoiceMetadata'):
         print_json_field("Invoice Metadata", desc['invoiceMetadata'])
     if desc.get('sshHostKey'):
@@ -916,6 +919,64 @@ def print_execution_desc(desc):
         if field not in recognized_fields:
             print_json_field(field, desc[field])
 
+
+def locale_from_currency_code(dx_code):
+    """
+    This is a (temporary) hardcoded mapping between currency_list.json in nucleus and standard
+    locale string useful for further formatting
+
+    :param dx_code: An id of nucleus/commons/pricing_models/currency_list.json collection
+    :return: standardised locale, eg 'en_US'; None when no mapping found
+    """
+    currency_locale_map = {0: 'en_US', 1: 'en_GB'}
+    return currency_locale_map[dx_code] if dx_code in currency_locale_map else None
+
+
+def format_currency_from_meta(value, meta):
+    """
+    Formats currency value into properly decorated currency string based on provided currency metadata.
+    Please note that this is very basic solution missing some of the localisation features (such as
+    negative symbol position and type.
+
+    Better option is to use 'locale' module to reflect currency string decorations more accurately.
+
+    See 'format_currency'
+
+    :param value:
+    :param meta:
+    :return:
+    """
+    prefix = '-' if value < 0 else ''  # .. TODO: some locales position neg symbol elsewhere, missing meta
+    prefix += meta['symbol'] if meta['symbolPosition'] == 'left' else ''
+    suffix = ' %s' % meta["symbol"] if meta['symbolPosition'] == 'right' else ''
+    # .. TODO: take the group and decimal separators from meta into account (US & UK are the same, so far we're safe)
+    formatted_value = '{:,.2f}'.format(abs(value))
+    return prefix + formatted_value + suffix
+
+
+def format_currency(value, meta, currency_locale=None):
+    """
+    Formats currency value into properly decorated currency string based on either locale (preferred)
+    or if that is not available then currency metadata. Until locale is provided from the server
+    a crude mapping between `currency.dxCode` and a locale string is used instead (eg 0: 'en_US')
+
+    :param value: amount
+    :param meta: server metadata (`currency`)
+    :return: formatted currency string
+    """
+    try:
+        if currency_locale is None:
+            currency_locale = locale_from_currency_code(meta['dxCode'])
+        if currency_locale is None:
+            return format_currency_from_meta(value, meta)
+        else:
+            locale.setlocale(locale.LC_ALL, currency_locale)
+            return locale.currency(value, grouping=True)
+    except locale.Error:
+        # .. locale is probably not available -> fallback to format manually
+        return format_currency_from_meta(value, meta)
+
+
 def print_user_desc(desc):
     print_field("ID", desc["id"])
     print_field("Name", desc["first"] + " " + ((desc["middle"] + " ") if desc["middle"] != '' else '') + desc["last"])
